@@ -7,7 +7,6 @@
 #        NOTES:  ---
 #       AUTHOR:  Michael Bochkaryov (Rattler), <misha@rattler.kiev.ua>
 #      COMPANY:  Net.Style
-#      VERSION:  1.0
 #      CREATED:  25.08.2009 14:12:44 EEST
 #===============================================================================
 
@@ -66,7 +65,7 @@ use 5.8.0;
 use strict;
 use warnings;
 
-use version; our $VERSION = "0.001";
+use version; our $VERSION = '0.021';
 
 use base qw(
   Exporter
@@ -734,7 +733,27 @@ None
 
 =head1 AUTHOR
 
+Valentyn Solomko <pere@pere.org.ua>
+
 Michael Bochkaryov <misha@rattler.kiev.ua>
 
+=head1 LICENSE
+
+Copyright (C) 2008 Michael Bochkaryov
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 =cut
 
